Methods to interop with null-terminated C strings.
This code is largely copied from the rust compiler’s small_c_string.rs.
Methods to interop with null-terminated C strings.
This code is largely copied from the rust compiler’s small_c_string.rs.